@@ -2,40 +2,6 @@ package Astro::FITS::Header::CFITSIO;
 
 # ---------------------------------------------------------------------------
 
-#+ 
-#  Name:
-#    Astro::FITS::Header::CFITSIO
-
-#  Purposes:
-#    Sub-class of Astro::FITS::Header, reads and write to FITS files
-
-#  Language:
-#    Perl object
-
-#  Description:
-#    This module sub-classes Astro::FITS::Header, which wraps a FITS 
-#    header block as a perl object as a hash containing an array of
-#    FITS::Header::Items and a lookup hash for the keywords. This 
-#    sub-class allows direct read and write from a raw FITS HDU on
-#    disk.
-
-#  Authors:
-#    Alasdair Allan (aa@astro.ex.ac.uk)
-#    Jim Lewis (jrl@ast.cam.ac.uk)
-#    Diab Jerius
-
-#  Revision:
-#     $Id$
-
-#  Copyright:
-#     Copyright (C) 2007-2009 Science & Technology Facilities Council.
-#     Copyright (C) 2001-2006 Particle Physics and Astronomy Research Council. 
-#     All Rights Reserved.
-
-#-
-
-# ---------------------------------------------------------------------------
-
 =head1 NAME
 
 Astro::FITS::Header::CFITSIO - Manipulates FITS headers from a FITS file
@@ -53,10 +19,13 @@ Astro::FITS::Header::CFITSIO - Manipulates FITS headers from a FITS file
 
 =head1 DESCRIPTION
 
-This module makes use of the L<CFITSIO|CFITSIO> module to read and write 
+This module makes use of the L<CFITSIO|CFITSIO> module to read and write
 directly to a FITS HDU.
 
-It stores information about a FITS header block in an object. Takes an hash as an arguement, with either an array reference pointing to an array of FITS header cards, or a filename, or (alternatively) and FITS identifier.
+It stores information about a FITS header block in an object. Takes an
+hash as an arguement, with either an array reference pointing to an
+array of FITS header cards, or a filename, or (alternatively) and FITS
+identifier.
 
 =cut
 
@@ -103,21 +72,21 @@ whether the file is opened ReadOnly.
 
 sub configure {
   my $self = shift;
-  
+
   my %args = ( ReadOnly => 0, @_ );
-  
-  # itialise the inherited status to OK.  
+
+  # itialise the inherited status to OK.
   my $status = 0;
   my $ifits;
 
-  return $self->SUPER::configure(%args) 
+  return $self->SUPER::configure(%args)
     if exists $args{Cards} or exists $args{Items};
 
   # read the args hash
   if (exists $args{fitsID}) {
      $ifits = $args{fitsID};
   } elsif (exists $args{File}) {
-     $ifits = Astro::FITS::CFITSIO::open_file( $args{File}, 
+     $ifits = Astro::FITS::CFITSIO::open_file( $args{File},
 		  $args{ReadOnly} ? Astro::FITS::CFITSIO::READONLY() :
 			            Astro::FITS::CFITSIO::READWRITE(),
 					       $status );
@@ -127,10 +96,10 @@ sub configure {
 
   # file sucessfully opened?
   if( $status == 0 ) {
-  
+
      # Get size of FITS header
      my ($numkeys, $morekeys);
-     $ifits->get_hdrspace( $numkeys, $morekeys, $status);      
+     $ifits->get_hdrspace( $numkeys, $morekeys, $status);
 
      # Set the FITS array to empty
      my @fits = ();
@@ -152,7 +121,7 @@ sub configure {
         $self->SUPER::configure( Cards => \@fits );
      } else {
         # Report bad exit status
-        croak("Error $status reading FITS array"); 
+        croak("Error $status reading FITS array");
      }
 
      # Look at the name of the file as it was passed in. If there is a FITS
@@ -177,18 +146,18 @@ sub configure {
        $self->subhdrs(@subfrms);
      }
   }
- 
+
   # clean up
   if ( $status != 0 ) {
      croak("Error $status opening FITS file");
   }
-  
+
   # close file, but only if we opened it
   $ifits->close_file( $status )
     unless exists $args{fitsID};
 
   return;
-  
+
 }
 
 # W R I T E H D R -----------------------------------------------------------
@@ -212,16 +181,16 @@ sub writehdr {
   my %args = @_;
 
   return $self->SUPER::configure(%args) if exists $args{Cards};
-   
-  # itialise the inherited status to OK.  
+
+  # itialise the inherited status to OK.
   my $status = 0;
-  my $ifits;   
-  
+  my $ifits;
+
   # read the args hash
   if (exists $args{fitsID}) {
      $ifits = $args{fitsID};
   } elsif (exists $args{File}) {
-     $ifits = Astro::FITS::CFITSIO::open_file( $args{File}, 
+     $ifits = Astro::FITS::CFITSIO::open_file( $args{File},
 			 Astro::FITS::CFITSIO::READWRITE(), $status );
   } else {
      croak("Argument hash does not contain fitsID, File or Cards");
@@ -258,7 +227,7 @@ sub writehdr {
     unless exists $args{fitsID};
 
   return;
-   
+
 }
 
 # T I M E   A T   T H E   B A R  --------------------------------------------
@@ -267,7 +236,7 @@ sub writehdr {
 
 =head1 NOTES
 
-This module requires Pete Ratzlaff's L<Astro::FITS::CFITSIO> module, 
+This module requires Pete Ratzlaff's L<Astro::FITS::CFITSIO> module,
 and  William Pence's C<cfitsio> subroutine library (v2.1 or greater).
 
 =head1 SEE ALSO
@@ -277,15 +246,27 @@ L<Astro::FITS::Header>, L<Astro::FITS::Header::Item>, L<Astro::FITS::Header::NDF
 =head1 AUTHORS
 
 Alasdair Allan E<lt>aa@astro.ex.ac.ukE<gt>,
-Jim Lewis E<lt>jrl@ast.cam.ac.ukE<gt>
+Jim Lewis E<lt>jrl@ast.cam.ac.ukE<gt>,
+Diab Jerius.
 
 =head1 COPYRIGHT
 
+Copyright (C) 2007-2009 Science & Technology Facilities Council.
 Copyright (C) 2001-2006 Particle Physics and Astronomy Research Council.
 All Rights Reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free Software
+Foundation; either version 3 of the License, or (at your option) any later
+version.
+
+This program is distributed in the hope that it will be useful,but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with
+this program; if not, write to the Free Software Foundation, Inc., 59 Temple
+Place,Suite 330, Boston, MA  02111-1307, USA
 
 =cut
 
